@@ -4,6 +4,8 @@ use strict;
 use warnings;
 use base 'Catalyst::Controller';
 
+use TestApp::Exception;
+
 sub ok : Local {
     my ( $self, $c ) = @_;
     
@@ -16,10 +18,22 @@ sub not_ok : Local {
     $c->forward( 'crash' );
 }
 
+sub not_ok_obj : Local {
+    my ( $self, $c ) = @_;
+    
+    $c->forward( 'crash_obj' );
+}
+
 sub crash : Local {
     my ( $self, $c ) = @_;
     
     three();
 }
 
+sub crash_obj : Local {
+    my ( $self, $c ) = @_;
+
+    die TestApp::Exception->new;
+}
+
 1;
